#!/bin/bash

if [ -f '/usr/sbin/wildix_shell_tools' ]; then
	. /usr/sbin/wildix_shell_tools
else
	logger -t "${0}" "ERROR: can't include wildix_shell_tools"
	exit 1
fi

CORES="$1" ; RAM="$2" ; AMAZON="$3" ; DOCKER="$4"

if [ -z $CORES ] || [ -z $RAM ] || [ -z $AMAZON ] || [ -z $DOCKER ]; then
	log "ERROR: zero values (exit)" "${0##*/}"
	exit 0
fi


N_CONF_LIMITS='/etc/nginx/conf.d/limits.conf'
N_CONF='/etc/nginx/nginx.conf'

# set parameters
if [ "$CORES" -gt "2" ] && [ "$RAM" -gt "2048" ]; then
	N_XMPP_RATE='10'
	N_WORKERS='worker_processes auto;
worker_cpu_affinity auto;'
else
	N_XMPP_RATE='5'
	N_WORKERS='worker_processes 1;'	
fi

if [ -f $N_CONF ]; then
	cat << END > $N_CONF
user wms;
$N_WORKERS
pid /run/nginx.pid;
include /etc/nginx/modules-enabled/*.conf;

events {
	worker_connections 8192;
	use epoll;
	multi_accept on;
}
END
fi


# set values for limits
[ -s "$N_CONF_LIMITS" ] && sed -i "/server_name zone=xmpp-server/s/rate=[0-9]\{1,3\}/rate=${N_XMPP_RATE}/g" $N_CONF_LIMITS
